boost_cropped: Portable C++ libraries (subset needed for Sage)
==============================================================

Description
-----------

Boost provides free peer-reviewed portable C++ source libraries.

We emphasize libraries that work well with the C++ Standard Library.
Boost libraries are intended to be widely useful, and usable across a
broad spectrum of applications. The Boost license encourages both
commercial and non-commercial use.

We aim to establish "existing practice" and provide reference
implementations so that Boost libraries are suitable for eventual
standardization. Ten Boost libraries are already included in the C++
Standards Committee's Library Technical Report (TR1) and will be in the
new C++0x Standard now being finalized. C++0x will also include several
more Boost libraries in addition to those from TR1. More Boost libraries
are proposed for TR2.

License
-------

Boost Software License - see http://www.boost.org/users/license.html


Upstream Contact
----------------

Website: http://www.boost.org/

See mailing list page at http://www.boost.org/community/groups.html

Dependencies
------------

None
